@@ -32,7 +32,6 @@
 #include "gdbusprivate.h"
 
 #include "glibintl.h"
-#include "gioalias.h"
 
 /**
  * SECTION:gdbuserror
@@ -868,6 +867,3 @@ g_dbus_error_encode_gerror (const GError *error)
 
   return error_name;
 }
-
-#define __G_DBUS_ERROR_C__
-#include "gioaliasdef.c"
